Module entity_parser

Module entity_parser 

Structs

ParsedEntity
Represents an entity parsed from a generated Rust file.
ParsedField
Represents a field parsed from a generated entity struct.

Functions

parse_entity_file
Parse an entity struct from a .rs file on disk.
parse_entity_source
Parse an entity struct from a Rust source string.