pub fn parse_entity_source(source: &str) -> Result<ParsedEntity, String>Expand description
Parse an entity struct from a Rust source string.
pub fn parse_entity_source(source: &str) -> Result<ParsedEntity, String>Parse an entity struct from a Rust source string.