build_module_name

Function build_module_name 

pub fn build_module_name(
    schema_name: &str,
    table_name: &str,
    has_multiple_schemas: bool,
) -> String
Build a module name, prefixing with schema when there are multiple schemas and the schema is not a well-known default.