Module codegen

Module codegen 

Modules

composite_gen
crud_gen
domain_gen
entity_parser
enum_gen
struct_gen

Structs

GeneratedFile
A generated code file with its content and required imports.

Functions

format_tokens_with_imports
generate
Generate all code for a given schema.
imports_for_derives
Returns the imports needed for well-known extra derives.
is_rust_keyword
Returns true if the given name is a Rust reserved keyword.
normalize_module_name
Normalize a table name for use as a Rust module/filename: replace multiple consecutive underscores with a single one.